@@ -18,8 +18,15 @@ def calc_energy(inputdata, DEBUG = False):
 
     # 計算結果を格納する変数
     resultJson = {
-        "E_hotwatersupply": 0,   # 給湯設備の設計一次エネルギー消費量
+        "E_hotwatersupply": 0,    # 給湯設備の設計一次エネルギー消費量 [MJ/年]
+        "Es_hotwatersupply": 0,   # 給湯設備の基準一次エネルギー消費量 [MJ/年]
+        "BEI_HW": 0,
         "hotwatersupply":{
+        },
+        "for_CGS":{
+            "Edesign_MWh_Ele_day": 0, # 給湯設備（エネルギー源を電力とする給湯機器のみが対象）の電力消費量
+            "Edesign_MJ_CGS_day": 0,  # 排熱利用する給湯系統の一次エネルギー消費量
+            "Q_eqp_CGS_day": 0        # 排熱が利用できる系統の給湯設備の給湯負荷
         }
     }
     
@@ -129,10 +136,10 @@ def calc_energy(inputdata, DEBUG = False):
             print(f'  - 日別給湯使用量（厨房） {np.sum(inputdata["HotwaterRoom"][room_name]["hotwater_demand_kitchen_daily"])}')
             print(f'  - 日別給湯使用量（その他） {np.sum(inputdata["HotwaterRoom"][room_name]["hotwater_demand_other_daily"])}')
 
-            np.savetxt("日別給湯使用量（手洗い）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_washroom_daily"]/inputdata["Rooms"][room_name]["roomArea"])
-            np.savetxt("日別給湯使用量（シャワー）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_shower_daily"]/inputdata["Rooms"][room_name]["roomArea"])
-            np.savetxt("日別給湯使用量（厨房）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_kitchen_daily"]/inputdata["Rooms"][room_name]["roomArea"])
-            np.savetxt("日別給湯使用量（その他）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_other_daily"]/inputdata["Rooms"][room_name]["roomArea"])
+            # np.savetxt("日別給湯使用量（手洗い）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_washroom_daily"]/inputdata["Rooms"][room_name]["roomArea"])
+            # np.savetxt("日別給湯使用量（シャワー）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_shower_daily"]/inputdata["Rooms"][room_name]["roomArea"])
+            # np.savetxt("日別給湯使用量（厨房）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_kitchen_daily"]/inputdata["Rooms"][room_name]["roomArea"])
+            # np.savetxt("日別給湯使用量（その他）_" + room_name + ".txt", inputdata["HotwaterRoom"][room_name]["hotwater_demand_other_daily"]/inputdata["Rooms"][room_name]["roomArea"])
 
 
 
@@ -210,9 +217,9 @@ def calc_energy(inputdata, DEBUG = False):
     elif inputdata["Building"]["Region"] == '8':
         TWdata = 0.6921*Toa_ave + 7.167
 
-    if DEBUG:
-        np.savetxt("日平均外気温度.txt", Toa_ave)
-        np.savetxt("日平均給水温度.txt", TWdata)
+    # if DEBUG:
+    #     np.savetxt("日平均外気温度.txt", Toa_ave)
+    #     np.savetxt("日平均給水温度.txt", TWdata)
 
 
     #----------------------------------------------------------------------------------
@@ -233,6 +240,10 @@ def calc_energy(inputdata, DEBUG = False):
                 inputdata["HotwaterRoom"][room_name]["HotwaterSystem"][unit_id]["RatedCapacity_total"]
 
     for room_name in inputdata["HotwaterRoom"]:
+
+        if DEBUG:
+            print(f'室名称 {room_name}')
+
         for unit_id, unit_configure in enumerate(inputdata["HotwaterRoom"][room_name]["HotwaterSystem"]):
 
             inputdata["HotwaterRoom"][room_name]["HotwaterSystem"][unit_id]["roomPowerRatio"] = \
@@ -240,6 +251,7 @@ def calc_energy(inputdata, DEBUG = False):
                 inputdata["HotwaterRoom"][room_name]["RatedCapacity_All"]
 
             if DEBUG:
+                print(f'機器名称 {unit_id}')
                 print(f'熱源比率 {inputdata["HotwaterRoom"][room_name]["HotwaterSystem"][unit_id]["roomPowerRatio"]}')
 
 
@@ -288,7 +300,7 @@ def calc_energy(inputdata, DEBUG = False):
             print(f'  - 日積算湯供給量 {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["Qsr_eqp_daily"])}')
             print(f'  - 日積算湯供給量（節湯込み） {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["Qs_eqp_daily"])}')
 
-            np.savetxt("日積算湯供給量（節湯込み）_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Qs_eqp_daily"])
+            # np.savetxt("日積算湯供給量（節湯込み）_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Qs_eqp_daily"])
             
 
     #----------------------------------------------------------------------------------
@@ -343,7 +355,7 @@ def calc_energy(inputdata, DEBUG = False):
             print(f'  - 配管熱損失 {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["Qp_eqp"])}')
             print(f'  - 配管熱損失係数 {inputdata["HotwaterSupplySystems"][unit_name]["heatloss_coefficient"]}')
 
-            np.savetxt("配管周囲温度.txt", Taround)
+            # np.savetxt("配管周囲温度.txt", Taround)
 
 
     # ----------------------------------------------------------------------------------
@@ -378,7 +390,7 @@ def calc_energy(inputdata, DEBUG = False):
             print(f'機器名称 {unit_name}')
             print(f'  - 太陽熱利用システムの熱利用量 {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["Qs_solargain"])}')
 
-            np.savetxt("太陽熱利用システムの熱利用量_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Qs_solargain"])
+            # np.savetxt("太陽熱利用システムの熱利用量_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Qs_solargain"])
 
     #----------------------------------------------------------------------------------
     # 解説書 5.6 年間給湯負荷
@@ -418,7 +430,7 @@ def calc_energy(inputdata, DEBUG = False):
             print(f'機器名称 {unit_name}')
             print(f'  - 日積算給湯負荷 {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["Qh_eqp_daily"])}')
 
-            np.savetxt("日積算給湯負荷_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Qh_eqp_daily"])
+            # np.savetxt("日積算給湯負荷_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Qh_eqp_daily"])
 
     #----------------------------------------------------------------------------------
     # 解説書 5.7 給湯設備の設計一次エネルギー消費量
@@ -443,13 +455,71 @@ def calc_energy(inputdata, DEBUG = False):
             print(f'  - 日別給湯負荷と配管熱損失 {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["Q_eqp"])}')
             print(f'  - 日別消費エネルギー消費量 {np.sum(inputdata["HotwaterSupplySystems"][unit_name]["E_eqp"])}')
 
-            np.savetxt("日別給湯負荷と配管熱損失_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Q_eqp"])
-            np.savetxt("日別消費エネルギー消費量_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["E_eqp"])
+            # np.savetxt("日別給湯負荷と配管熱損失_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["Q_eqp"])
+            # np.savetxt("日別消費エネルギー消費量_" + unit_name + ".txt", inputdata["HotwaterSupplySystems"][unit_name]["E_eqp"])
 
     if DEBUG:
         print(f'設計一次エネルギー消費量 {resultJson["E_hotwatersupply"]} MJ/年')
 
 
+    #----------------------------------------------------------------------------------
+    # 解説書 10.4 給湯設備の基準一次エネルギー消費量
+    #----------------------------------------------------------------------------------
+
+    for room_name in inputdata["HotwaterRoom"]:
+
+        # 建物用途、室用途（可読性重視で一旦変数に代入する）
+        buildingType = inputdata["Rooms"][room_name]["buildingType"]
+        roomType     = inputdata["Rooms"][room_name]["roomType"]
+    
+        resultJson["Es_hotwatersupply"] += \
+            bc.RoomStandardValue[buildingType][roomType]["給湯"][inputdata["Building"]["Region"]+"地域"] * \
+            inputdata["Rooms"][room_name]["roomArea"]
+
+    # BEI/HW
+    resultJson["BEI_HW"] = resultJson["E_hotwatersupply"] / resultJson["Es_hotwatersupply"]
+
+
+    #----------------------------------------------------------------------------------
+    # CGS計算用変数 （解説書 ８章 附属書 G.10 他の設備の計算結果の読み込み）
+    #----------------------------------------------------------------------------------
+
+    Edesign_MWh_Ele_hour = np.zeros((365,24))
+    Edesign_MJ_CGS_hour  = np.zeros((365,24))
+    Q_eqp_CGS_hour       = np.zeros((365,24))
+
+    if len(inputdata["CogenerationSystems"]) == 1: # コジェネがあれば実行
+    
+        for cgs_name in inputdata["CogenerationSystems"]:
+
+            # コジェネ系統にない給湯設備の電力消費量を積算
+            for unit_name in inputdata["HotwaterSupplySystems"]:
+                
+                if inputdata["CogenerationSystems"][cgs_name]["HowWaterSystem"] != "" and \
+                    inputdata["CogenerationSystems"][cgs_name]["HowWaterSystem"] == unit_name:
+
+                    # コジェネの排熱利用先であれば
+                    for dd in range(0,365):
+                        Edesign_MJ_CGS_hour[dd] += inputdata["HotwaterSupplySystems"][unit_name]["E_eqp"][dd]/24/1000 * np.ones(24)
+                        Q_eqp_CGS_hour[dd] += inputdata["HotwaterSupplySystems"][unit_name]["Q_eqp"][dd]/24/1000 * np.ones(24)
+
+                else:
+
+                    # コジェネの排熱利用先以外であれば
+                    for unit_id, unit_configure in enumerate(inputdata["HotwaterSupplySystems"][unit_name]["HeatSourceUnit"]):
+                    
+                        if unit_configure["UsageType"] == "給湯負荷用":
+                            if unit_configure["HeatSourceType"] == "電気瞬間湯沸器" or unit_configure["HeatSourceType"] == "貯湯式電気温水器" or \
+                                unit_configure["HeatSourceType"] == "業務用ヒートポンプ給湯機" or unit_configure["HeatSourceType"] == "家庭用ヒートポンプ給湯機":
+
+                                for dd in range(0,365):
+                                    Edesign_MWh_Ele_hour[dd] += inputdata["HotwaterSupplySystems"][unit_name]["E_eqp"][dd]/24/1000/9760 * np.ones(24)
+
+
+        resultJson["for_CGS"]["Edesign_MWh_Ele_day"] = np.sum(Edesign_MWh_Ele_hour,1)
+        resultJson["for_CGS"]["Edesign_MJ_CGS_day"]  = np.sum(Edesign_MJ_CGS_hour,1)
+        resultJson["for_CGS"]["Q_eqp_CGS_day"]       = np.sum(Q_eqp_CGS_hour,1)
+
     return resultJson
 
 
@@ -457,12 +527,15 @@ def calc_energy(inputdata, DEBUG = False):
 if __name__ == '__main__':
 
     print('----- hotwatersupply.py -----')
-    filename = './sample/hotwater_C1_節湯.json'
+    # filename = './sample/CGS_case_office_00.json'
+    filename = './tests/cogeneration/Case_hotel_00.json'
 
     # 入力データ（json）の読み込み
     with open(filename, 'r') as f:
         inputdata = json.load(f)
 
     resultJson = calc_energy(inputdata, DEBUG = True)
-    print(resultJson)
+
+    with open("resultJson_HW.json",'w') as fw:
+        json.dump(resultJson, fw, indent=4, ensure_ascii=False, cls = bc.MyEncoder)
 
