@@ -13,20 +13,6 @@ database_directory =  os.path.dirname(os.path.abspath(__file__)) + "/database/"
 climatedata_directory =  os.path.dirname(os.path.abspath(__file__)) + "/climatedata/"
 
 
-# json.dump用のクラス
-class MyEncoder(json.JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, np.integer):
-            return int(obj)
-        elif isinstance(obj, np.floating):
-            return float(obj)
-        elif isinstance(obj, np.ndarray):
-            return obj.tolist()
-        elif isinstance(obj, set):
-            return list(obj)
-        else:
-            return super(MyEncoder, self).default(obj)
-
 ## 中間期平均外気温（附属書B.1）
 def set_OutdoorTemperature(region):
     if region == "1":
@@ -55,18 +41,17 @@ def calc_energy(inputdata, DEBUG = False):
     
     # 計算結果を格納する変数
     resultJson = {
-        "E_ventilation": 0,
-        "Es_ventilation": 0,
+        "E_ventilation": 0,  # 設計一次エネルギー消費量 [GJ]
+        "E_ventilation_hourly": np.zeros((365,24)),  # 設計一次エネルギー消費量 [GJ]
+        "Es_ventilation": 0, # 基準一次エネルギー消費量 [GJ]
         "BEI_V": 0,
         "ventilation":{   
+        },
+        "for_CGS":{
+            "Edesign_MWh_day": np.zeros(365)
         }
     }
 
-    # 変数初期化
-    E_ventilation = 0    # 設計一次エネルギー消費量 [GJ]
-    Es_ventilation = 0   # 基準一次エネルギー消費量 [GJ]
-
-
     # 室毎（換気系統毎）のループ
     for roomID, isys in inputdata["VentilationRoom"].items():
 
@@ -83,6 +68,7 @@ def calc_energy(inputdata, DEBUG = False):
         ## 年間換気運転時間 （解説書 B.2）
         ##----------------------------------------------------------------------------------
         inputdata["VentilationRoom"][roomID]["opeTime"] = bc.RoomUsageSchedule[buildingType][roomType]["年間換気時間"]
+        inputdata["VentilationRoom"][roomID]["opeTime_hourly"] = bc.get_dailyOpeSchedule_ventilation(buildingType, roomType)
 
         # 接続されている換気機器の種類に応じて集計処理を実行
         inputdata["VentilationRoom"][roomID]["isVentilationUsingAC"] = False
@@ -124,8 +110,11 @@ def calc_energy(inputdata, DEBUG = False):
             # 室の運転時間を追加
             if "opeTimeList" in inputdata["VentilationUnit"][unitID]:
                 inputdata["VentilationUnit"][unitID]["opeTimeList"].append(inputdata["VentilationRoom"][roomID]["opeTime"])
+                inputdata["VentilationUnit"][unitID]["opeTimeList_hourly"].append(inputdata["VentilationRoom"][roomID]["opeTime_hourly"])
             else:
                 inputdata["VentilationUnit"][unitID]["opeTimeList"] = [inputdata["VentilationRoom"][roomID]["opeTime"]]
+                inputdata["VentilationUnit"][unitID]["opeTimeList_hourly"] = [inputdata["VentilationRoom"][roomID]["opeTime_hourly"]]
+
 
             # 室の床面積を追加
             if "roomAreaList" in inputdata["VentilationUnit"][unitID]:
@@ -185,8 +174,14 @@ def calc_energy(inputdata, DEBUG = False):
 
         # 床面積の合計
         inputdata["VentilationUnit"][unitID]["roomAreaTotal"] = sum( iunit["roomAreaList"] )
+
         # 最大の運転時間
-        inputdata["VentilationUnit"][unitID]["maxopeTime"] = max( iunit["opeTimeList"] )
+        inputdata["VentilationUnit"][unitID]["maxopeTime"] = 0
+        inputdata["VentilationUnit"][unitID]["maxopeTime_hourly"] = np.zeros((365,24))
+        for opeTime_id, opeTime_V in enumerate(iunit["opeTimeList"]):
+            if inputdata["VentilationUnit"][unitID]["maxopeTime"] < opeTime_V:
+                inputdata["VentilationUnit"][unitID]["maxopeTime"] = opeTime_V
+                inputdata["VentilationUnit"][unitID]["maxopeTime_hourly"] = inputdata["VentilationUnit"][unitID]["opeTimeList_hourly"][opeTime_id]
 
         # 換気代替空調機と換気送風機が混在していないかをチェック　→　混在していたらエラー
         if not all(iunit["isVentilationUsingAC"]) and any(iunit["isVentilationUsingAC"]):
@@ -199,6 +194,7 @@ def calc_energy(inputdata, DEBUG = False):
         # 各室の計算結果を格納
         resultJson["ventilation"][roomID] = {
                 "PrimaryEnergy": 0,
+                "PrimaryEnergy_hourly": np.zeros((365,24)),
                 "StandardEnergy": 0
         }
 
@@ -253,18 +249,32 @@ def calc_energy(inputdata, DEBUG = False):
                         else:
                             raise Exception('Error!')
 
+                        # 換気代替空調機本体
                         resultJson["ventilation"][roomID]["PrimaryEnergy"] += \
                             ( inputdata["VentilationUnit"][unitID]["AC_CoolingCapacity"] * xL / (2.71 * inputdata["VentilationUnit"][unitID]["AC_RefEfficiency"] )  \
                             + inputdata["VentilationUnit"][unitID]["AC_PumpPower"] /0.75 ) \
+                            * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
                             * inputdata["VentilationUnit"][unitID]["maxopeTime"] * bc.fprime * 10**(-3) * Cac
 
+                        # 時刻別
+                        resultJson["ventilation"][roomID]["PrimaryEnergy_hourly"] += \
+                            ( inputdata["VentilationUnit"][unitID]["AC_CoolingCapacity"] * xL / (2.71 * inputdata["VentilationUnit"][unitID]["AC_RefEfficiency"] )  \
+                            + inputdata["VentilationUnit"][unitID]["AC_PumpPower"] /0.75 ) \
+                            * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
+                            * inputdata["VentilationUnit"][unitID]["maxopeTime_hourly"] * bc.fprime * 10**(-3) * Cac
+
                     # 空調機に付属するファン
                     resultJson["ventilation"][roomID]["PrimaryEnergy"] += \
                         inputdata["VentilationUnit"][unitID]["Energy_kW"]  \
                         * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
                         * inputdata["VentilationUnit"][unitID]["maxopeTime"] * bc.fprime * 10**(-3) * Cac
 
-                    print(inputdata["VentilationUnit"][unitID]["Energy_kW"])
+                    # 時刻別
+                    resultJson["ventilation"][roomID]["PrimaryEnergy_hourly"] += \
+                        inputdata["VentilationUnit"][unitID]["Energy_kW"]  \
+                        * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
+                        * inputdata["VentilationUnit"][unitID]["maxopeTime_hourly"] * bc.fprime * 10**(-3) * Cac
+
 
                 else: ## 換気代替空調機と併設される送風機
 
@@ -273,6 +283,12 @@ def calc_energy(inputdata, DEBUG = False):
                         * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
                         * inputdata["VentilationUnit"][unitID]["maxopeTime"] * bc.fprime * 10**(-3) * Cfan
 
+                    # 時刻別
+                    resultJson["ventilation"][roomID]["PrimaryEnergy_hourly"] += \
+                        inputdata["VentilationUnit"][unitID]["Energy_kW"]  \
+                        * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
+                        * inputdata["VentilationUnit"][unitID]["maxopeTime_hourly"] * bc.fprime * 10**(-3) * Cfan
+
 
                 if DEBUG:
                     print( f'室名称 {roomID}, 機器名称 {unitID}')
@@ -289,28 +305,51 @@ def calc_energy(inputdata, DEBUG = False):
                     * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
                     * inputdata["VentilationUnit"][unitID]["maxopeTime"] * bc.fprime * 10**(-3)
 
+                # 時刻別
+                resultJson["ventilation"][roomID]["PrimaryEnergy_hourly"] += inputdata["VentilationUnit"][unitID]["Energy_kW"]  \
+                    * inputdata["VentilationRoom"][roomID]["roomArea"] / inputdata["VentilationUnit"][unitID]["roomAreaTotal"] \
+                    * inputdata["VentilationUnit"][unitID]["maxopeTime_hourly"] * bc.fprime * 10**(-3)
 
-        ##----------------------------------------------------------------------------------
-        ## 基準一次エネルギー消費量 [MJ] （解説書 10）
-        ##----------------------------------------------------------------------------------
-        resultJson["ventilation"][roomID]["StandardEnergy"] = bc.RoomStandardValue[buildingType][roomType]["換気"] * inputdata["VentilationRoom"][roomID]["roomArea"]
+
+    ##----------------------------------------------------------------------------------
+    ## 基準一次エネルギー消費量 [MJ] （解説書 10.2）
+    ##----------------------------------------------------------------------------------
+    for roomID, isys in inputdata["VentilationRoom"].items():
+
+        # 建物用途、室用途（可読性重視で一旦変数に代入する）
+        buildingType = inputdata["Rooms"][roomID]["buildingType"]
+        roomType     = inputdata["Rooms"][roomID]["roomType"]
+    
+        resultJson["ventilation"][roomID]["StandardEnergy"] = \
+            bc.RoomStandardValue[buildingType][roomType]["換気"] * inputdata["Rooms"][roomID]["roomArea"]
 
 
     # 結果の集計
     for roomID, isys in inputdata["VentilationRoom"].items():
         resultJson["E_ventilation"]  += resultJson["ventilation"][roomID]["PrimaryEnergy"]
+        resultJson["E_ventilation_hourly"]  += resultJson["ventilation"][roomID]["PrimaryEnergy_hourly"]
         resultJson["Es_ventilation"] += resultJson["ventilation"][roomID]["StandardEnergy"]
 
+    # 値の検証
+    if (resultJson["E_ventilation"] - np.sum(np.sum(resultJson["E_ventilation_hourly"]))) < 0.000001:
+        print('年積算値と時刻別の値は一致しています。')
+    else:
+        print(resultJson["E_ventilation"])
+        print(np.sum(np.sum(resultJson["E_ventilation_hourly"])))
+
+
     # BEI/V [-]
-    if Es_ventilation <= 0:
+    if resultJson["Es_ventilation"] <= 0:
         resultJson["BEI_V"]  = None
     else:
         resultJson["BEI_V"]  = resultJson["E_ventilation"] / resultJson["Es_ventilation"]
 
-    if DEBUG:
-        # with open("resultJson.json",'w') as fw:
-        #     json.dump(resultJson, fw, indent=4, ensure_ascii=False, cls = MyEncoder)
 
+    # コジェネ用の結果の格納 [MJ → MWh]
+    for day in range(0,365):
+        resultJson["for_CGS"]["Edesign_MWh_day"][day] = np.sum(resultJson["E_ventilation_hourly"][day]) / (bc.fprime) 
+
+    if DEBUG:
         print( f'設計一次エネルギー消費量[MJ] {resultJson["E_ventilation"]}')
         print( f'基準一次エネルギー消費量[MJ] {resultJson["Es_ventilation"]}')
 
@@ -321,11 +360,13 @@ def calc_energy(inputdata, DEBUG = False):
 if __name__ == '__main__':
 
     print('----- ventilation.py -----')
-    filename = './sample/WEBPRO_inputSheet_for_Ver3.json'
+    filename = './sample/sample01_WEBPRO_inputSheet_for_Ver2.5.json'
 
     # テンプレートjsonの読み込み
     with open(filename, 'r') as f:
         inputdata = json.load(f)
 
     resultJson = calc_energy(inputdata, DEBUG = True)
-    print(resultJson)
\ No newline at end of file
+
+    with open("resultJson_V.json",'w') as fw:
+        json.dump(resultJson, fw, indent=4, ensure_ascii=False, cls = bc.MyEncoder)
\ No newline at end of file
